*
*     NNPDF tutorial: How to compute the photon PDF central value
*     and 1-sigma error band in Fortran, using LHAPDF interface.
*
*     Compile with:
*     gfortran tutorial.f -o tutorial_fortran 
*     -L $(shell lhapdf-config --libdir) -lLHAPDF
*
*     Author: Stefano Carrazza for The NNPDF Collaboration - 2013
*
      program tutorial
      implicit none

*     Declaring variables
      integer i, n
      integer NxPoints
      integer NumberReplicas
      double precision Q, x
      double precision xpdfCV(-6:6),xphotonCV
      double precision xpdfError(-6:6),xphotonError
      double precision xpdfErr
      double precision xmin, xmax
      double precision delta
      double precision ErrorBand(1000)
      double precision ComputeStdDev
      
*     Initializing variables
      NxPoints = 50
      Q = 2.d0**0.5
      xmin = dlog(1d-5)
      xmax = dlog(1.d0)
      delta = (xmax - xmin)/NxPoints

*     Loading the NNPDF set
      call InitPDFsetByName("NNPDF23_nlo_as_0119_qed.LHgrid")
      call numberPDF(NumberReplicas)


*     Getting the central values
      do i = 0, NxPoints-1

         ! Replica 0 == Central Value (AVG)
         call InitPDF(0)
         x = exp(xmin + i*delta)
         call evolvePDFphoton(x,Q,xpdfCV,xphotonCV)

         ! Computing 1-sigma error band
         do n = 1, NumberReplicas
            call InitPDF(n)
            call evolvePDFphoton(x,Q,xpdfError,xphotonError)
            ErrorBand(n) = xphotonError
         enddo
         
         xpdfErr = ComputeStdDev(NumberReplicas,
     1        ErrorBand, xphotonCV)

         ! Printing results
         write(6,441) "x = ",x, " xphoton(x,Q) = (",
     1        xphotonCV," +/- ",xpdfErr,")"
      enddo

 441  format(a,f15.10,a,f15.10,a,f15.10,a)

      stop
      end

*     Computes the standard deviation
      function ComputeStdDev(n,x,cv)
      integer i, n
      double precision sum, cv
      double precision x(n)
      double precision ComputeStdDev

      sum = 0.d0
      do i= 1, n
         sum = sum + (x(i)-cv)**2
      enddo
      
      sum = sum/(n-1)
      ComputeStdDev = sqrt(sum)

      return 
      end
